[MKDoc-commit] Survey grace period changed from 7 days to 21 days

chris at mkdoc.demon.co.uk chris at mkdoc.demon.co.uk
Tue Feb 27 11:10:53 GMT 2007


Log Message:
-----------
Survey grace period changed from 7 days to 21 days

Tags:
----
mkdoc-1-6

Modified Files:
--------------
    mkd/tools:
        ufi_survey_mailer.pl

-------------- next part --------------
Index: ufi_survey_mailer.pl
===================================================================
RCS file: /var/spool/cvs/mkd/tools/Attic/ufi_survey_mailer.pl,v
retrieving revision 1.1.2.14
retrieving revision 1.1.2.15
diff -Ltools/ufi_survey_mailer.pl -Ltools/ufi_survey_mailer.pl -u -r1.1.2.14 -r1.1.2.15
--- tools/ufi_survey_mailer.pl
+++ tools/ufi_survey_mailer.pl
@@ -141,13 +141,13 @@
         }
     }
 
     # send the summary when a survey ended 8 days ago (users may enter
     # data for 7 days past the end date)
     if (my $previous = previous_survey()) {
         my $diff = DateTime->now() - $previous->{end_date};
         my ($years, $months, $days) = 
           $diff->in_units('years', 'months', 'days');
-        if ($years == 0 and $months == 0 and $days == 8) {
+        if ($years == 0 and $months == 0 and $days == 22) {
             send_summary($previous);
         }
     }
@@ -269,7 +269,7 @@
     return {id         => $id,
             start_date => _parse_mysql_date($start_date),
             end_date   => _parse_mysql_date($end_date),
-            final_date => _parse_mysql_date($end_date)->add(days => 7)};
+            final_date => _parse_mysql_date($end_date)->add(days => 21)};
 
 }
 
@@ -141,13 +141,13 @@
     }
 
-    # send the summary when a survey ended 8 days ago (users may enter
-    # data for 7 days past the end date)
+    # send the summary when a survey ended 22 days ago (users may enter
+    # data for 21 days past the end date)
     if (my $previous = previous_survey()) {
         my $diff = DateTime->now() - $previous->{end_date};


More information about the MKDoc-commit mailing list